\name{Ginv}
\alias{Ginv}
\title{
  Compute Generalized Inverse of Input Matrix
}
\description{
Singular value decomposition (svd) is used to compute a
generalized inverse of input matrix.
}
\usage{
Ginv(x)
}
\arguments{

\item{x}{
A matrix.
}
}
\value{
List with components:

\item{Ginv}{
Generalized inverse of x.
}
\item{rank}{
Rank of matrix x.
}
}
\section{Side Effects}{

}
\details{
The function svd is used to compute the singular values of
the input matrix, and the rank of the matrix is determined
by the number of singular values  that  are  at  least  as
large   as  max(svd)*eps,  where  eps  is  a  small  value
(currently eps = .000001).
}
\section{References}{
Press  WH,  Teukolsky  SA,  Vetterling  WT,  Flannery  BP.
Numerical  recipes  in C. The art of scientific computing.
2nd ed. Cambridge University Press,  Cambridge.1992.  page
61.
}
\seealso{
svd
}
\examples{
# for matrix x, extract the generalized inverse and 
# rank of x as follows
#   > save <- Ginv(x)
#   > ginv.x <- save$Ginv
#   > rank.x <- save$rank
}
\keyword{}
% docclass is function
% Converted by Sd2Rd version 1.21.

\eof
\name{allele.recode}
\alias{allele.recode}
\title{
  Recode allele values to integer ranks
}
\description{
Genotypes for subjects represented by a pair  of  vectors,
with the vectors containing allele values (either numeric,
factor, or character), are recoded to the  rank  order  of
allele values.
}
\usage{
allele.recode(a1, a2, miss.val=NA)
}
\arguments{
\item{a1}{
Vector of "first" alleles.
}
\item{a2}{
Vector of "second" alleles.
}
\item{miss.val }{
Vector of missing value codes for alleles.
}
}
\value{
List with components:

\item{a1}{
Vector of recoded "first" alleles.
}
\item{a2}{
Recode of recoded "second" alleles.
}
\item{allele.label}{
Vector of labels for unique alleles.
}
}
\section{Side Effects}{

}
\details{
If alleles are numeric, they are recoded to the rank order
of the alleles.  If the alleles are factor or character,
they are recoded to interger values that correspond to the
indices of the sorted values of the unique alleles, but
sorted as character values.
}
\section{References}{

}
\seealso{
geno.recode
}
\examples{

}
\keyword{}
% docclass is function
% Converted by Sd2Rd version 1.21.

\eof
\name{dglm.fit}
\alias{dglm.fit}
\title{
  Density function for GLM fit
}
\description{
For internal use within the haplo.stats library
}
\usage{
dglm.fit(fit)
}
\arguments{

\item{fit}{

}
}
\value{
}
\section{Side Effects}{

}
\details{
For internal use within the haplo.stats library
}
\section{References}{

}
\seealso{

}
\examples{

}
\keyword{}
% docclass is function
% Converted by Sd2Rd version 1.21.

\eof
\name{geno.count.pairs}
\alias{geno.count.pairs}
\title{
  Counts of Total Haplotype Pairs Produced by Genotypes 
}
\description{
Provide a count of all possible haplotype pairs for each subject,
according to the phenotypes in the rows of the geno matrix.  
The count for each row includes the count for complete phenotypes, as 
well as possible haplotype pairs for phenotypes where there are
missing alleles at any of the loci.
}
\usage{
geno.count.pairs(geno)
}
\arguments{
\item{geno}{
Matrix of alleles, such that each locus has a  pair  of adjacent 
columns of alleles,  and the order of columns corresponds to the 
order of loci  on a chromosome.   If there are K loci, then geno 
has  2*K  columns.  Rows represent all observed alleles for each 
subject, their phenotype.
}

}
\value{
Vector where each element gives a count of the number haplotype pairs 
that are consistent with a  subject's phenotype, where a phenotype may
include 0, 1, or 2 missing alleles at any locus.
}
\section{Side Effects}{

}
\details{
When a subject has no missing alleles, and has h heterozygous sites, 
there are 2**(h-1) haplotype pairs that are possible ('**'=power).
For loci with missing alleles, we consider all possible pairs of alleles 
at those loci.  Suppose that there are M loci with missing alleles, and 
let the vector V have values 1 or 0 acccording to whether these loci 
are imputed to be heterozygous or homozygous, respectively. The length
of V is M.  The total number of  possible states of V is 
2**M. Suppose that  the vector W, also of length M, provides a count
of the number of possible heterozygous/homozygous states at the loci
with missing data. For example, if one allele  is missing, and there
are K possible alleles at that locus, then there can be one homozygous
and (K-1) heterozygous genotypes. If two alleles are missing, there
can be K homozygous and K(K-1)/2 heterozygous genotypes. Suppose the
function H(h+V) counts the total number of heterozygous sites among
the loci without missing data (of which h are heterozygous) and the
imputed loci (represented by the  vector V). Then, the total number of
possible pairs of haplotypes can be respresented as SUM(W*H(h+V)),
where the sum is over all possible values for the vector V.
}
\seealso{
\code{\link{haplo.em}},
\code{\link{summaryGeno}}
}
\examples{
setupData(hla.demo)
geno <- hla.demo[,c(17,18,21:24)]
geno <- geno.recode(geno)$grec
count.geno <- geno.count.pairs(geno)
print(count.geno)
}
\keyword{}
% docclass is function
% Converted by Sd2Rd version 1.21.

\eof
\name{geno.recode}
\alias{geno.recode}
\title{
  Recode Genotypes
}
\description{
For all loci as pairs of columns in a matrix, recode
alleles
}
\usage{
geno.recode(geno, miss.val=0)
}
\arguments{
\item{geno}{
Matrix of alleles, such that each locus has a  pair  of
adjacent  columns  of  alleles.  If there are K loci, then
ncol(geno) = 2*K. Rows represent alleles for each subject.
}
\item{miss.val }{
Vector of codes for missing values of alleles.
}
}
\value{
List with components:

\item{grec}{
Matrix of recoded alleles - see allele.recode
}
\item{alist}{
List of allele labels.  For K loci, there are K
components in the list, and the kth  component is a vector
of sorted unique allele labels for the kth locus.
}
}
\section{Side Effects}{

}
\details{

}
\section{References}{

}
\seealso{
allele.recode
}
\examples{

}
\keyword{}
% docclass is function
% Converted by Sd2Rd version 1.21.

\eof
%  $Author: sinnwell $ 
%  $Date: 2004/03/12 17:56:54 $
%  $Header: /people/biostat3/sinnwell/Rdir/Make/RCS/glm.fit.nowarn.Rd,v 1.3 2004/03/12 17:56:54 sinnwell Exp $
%  $Locker:  $ 

\name{glm.fit.nowarn}
\alias{glm.fit.nowarn}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Modified from glm.fit function to not warn users for binomial
  non-integer weights. }
\description{
 An internal function for the haplo.stats library
}
\usage{
glm.fit.nowarn(x, y, weights = rep(1, nobs), start = NULL,
             etastart = NULL, mustart = NULL, offset = rep(0,nobs),
             family=gaussian(), control=glm.control(), intercept=TRUE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{  \code{x} }
  \item{y}{  \code{y} }
  \item{weights}{ \code{weights} }
  \item{start}{  \code{start} }
  \item{etastart}{  \code{etastart} }
  \item{mustart}{  \code{mustart} }
  \item{offset}{  \code{offset} }
  \item{family}{  \code{family} }
  \item{control}{ \code{control} }
  \item{intercept}{ \code{intercept} }
}
\details{
 
}
\value{ }
\references{  }
\author{ Sinnwell JP }
\note{ }

% ~Make other sections like Warning with \section{Warning }{....} ~ 
\seealso{ \code{\link{haplo.glm}} }
\examples{ }
\keyword{ }% at least one, from doc/KEYWORDS


\eof
\name{haplo.em}
\alias{haplo.em}
\title{
  EM Computation of Haplotype Probabilities, with Progressive Insertion
of Loci
}
\description{
  For genetic marker phenotypes measured on unrelated subjects, with 
  linkage phase unknown, compute maximum likelihood estimates of
  haplotype probabilities.  Because linkage phase is unknown, there 
  may be  more than one pair of haplotypes that are consistent with 
  the oberved marker phenotypes, so posterior probabilities of pairs 
  of haplotypes for each subject are also computed. Unlike the usual EM
  which attempts to enumerate all possible pairs of haplotypes before
  iterating over the EM steps,  this "progressive insertion" algorithm 
  progressively inserts batches of loci into haplotypes of growing
  lengths, runs the EM steps, trims off
  pairs of haplotypes per subject when the posterior probability of the
  pair is below a specified threshold, and then continues these
  insertion, EM, and trimming steps until all loci are inserted into the
  haplotype. The user can choose the batch size. If the batch size
  is chosen to be all loci, and the threshold for trimming is set to
  0, then this algorithm reduces to the usual EM algorithm.
}
\usage{
haplo.em(geno, locus.label=NA, miss.val=c(0, NA), weight, control= 
           haplo.em.control())
}
\arguments{
\item{geno}{
  matrix of alleles, such that each locus has a pair of adjacent 
  columns of alleles, and the order of columns corresponds to 
  the order of loci on a chromosome.  If there are K loci, then 
  ncol(geno) = 2*K. Rows represent the alleles for each subject.
}
\item{locus.label }{
  vector of labels for loci.
}
\item{miss.val }{
  vector of values that represent missing alleles in geno.
}
\item{weight}{
  weights for observations (rows of geno matrix).  
}
\item{control}{
  list of control parameters. The default is constructed by the function
  haplo.em.control. The default behavior of this function results in the
  following parameter settings:  loci.insert.order=1:n.loci, 
  insert.batch.size=min(4,n.loci), min.posterior= 0.0001, tol=0.00001,
  max.iter=500, random.start=0 (no random start), iseed=NULL (no saved
  seed to start random start), verbose=0 (no printout during EM
  iterations). See haplo.em.control for more details.
}
}
\value{
  list with components:

\item{converge}{
indicator of convergence of the EM algorithm
  (1 = converge, 0 = failed).
}
\item{lnlike}{
value of lnlike at last EM iteration (maximum lnlike if converged).
}
\item{lr}{
likelihood ratio statistic to test the final lnlike against the
  lnlike that assumes complete linkage equilibrium among all loci
  (i.e., haplotype frequencies are products of allele frequencies).
}
\item{df.lr}{
degrees of freedom for likelihood ratio statistic. The df for the
  unconstrained final model is the  number of non-zero haplotype frequencies
  minus 1, and the df for the null model of complete linkage 
  equilibrium is the sum, over all loci, of (number of alleles - 1). The
  df for the lr statistic is df[unconstrained] - df[null]. This can
  result in negative df, if many haplotypes are estimated to have zero 
  frequency, or if a large amount of trimming occurs, when using large
  values of min.posterior in the list of control parameters.
}
\item{hap.prob}{
vector of mle's of haplotype probabilities.  The ith
  element of hap.prob corresponds to the ith row of 
  haplotype.
}
\item{locus.label}{
vector of labels for loci, of length K 
(see definition of input values).
}
\item{subj.id}{
vector of id's for subjects used in the analysis, based on row number
  of input geno matrix. If subjects are removed, then their id will be
  missing from subj.id.
}
\item{rows.rem}{
now defunct, but set equal to a vector of length 0, to be compatible 
  with other functions that check for rows.rem.
}
\item{indx.subj}{
vector for row index of subjects after expanding to all 
 possible pairs of haplotypes for each person.  If indx.subj=i, 
 then i is the ith row of  geno.  If the ith 
 subject has n possible pairs of haplotypes that correspond 
 to their marker genotype, then i is repeated n times.
}
\item{nreps}{
vector for the count of haplotype pairs that map to
  each subject's marker genotypes.
}
\item{max.pairs}{
vector of maximum number of pairs of haplotypes per subject that are
  consistent with their marker data in the matrix geno. The
  length of max.pairs  = nrow(geno). This vector is computed by  
  geno.count.pairs.
}
\item{hap1code}{
vector of codes for each subject's first haplotype.
  The values in hap1code are the row numbers of the unique
  haplotypes in the returned matrix haplotype.
}
\item{hap2code}{
similar to hap1code, but for each subject's second haplotype.
}
\item{post}{
vector of posterior probabilities of pairs of haplotypes for 
  a person, given their marker phenotypes.
}
\item{haplotype}{
matrix of unique haplotypes. Each row represents a unique 
  haplotype, and the number of columns is the number of loci.
}
\item{control}{
list of control parameters for algorithm. See haplo.em.control
}
}
\section{Side Effects}{

}
\details{

}
\section{References}{
  The basis of this progressive insertion algorithm is from the sofware
  snphap by David Clayton. Although some of the features and control
  parameters of this S-PLUS version are modeled after snphap, there are
  substantial differences, such as extension to allow for more than two
  alleles per locus, and some other nuances on how the alogrithm is implemented.
}
\seealso{
  haplo.em.control
}
\examples{
setupData(hla.demo)
attach(hla.demo)
geno <- hla.demo[,c(17,18,21:24)]
label <-c("DQB","DRB","B")
keep <- !apply(is.na(geno) | geno==0, 1, any)

save.em.keep <- haplo.em(geno=geno[keep,], locus.label=label)

# warning: output will not exactly match

print.haplo.em(save.em.keep)
}
\keyword{}
% docclass is function
% Converted by Sd2Rd version 1.21.

\eof
\name{haplo.em.control}
\alias{haplo.em.control}
\title{
  Create the Control Parameters for the EM Computation of Haplotype 
Probabilities, with Progressive Insertion of Loci
}
\description{
This function creates a list of parameters that control the 
EM algorithm based on progressive insertion of loci.
Non-default parameters for the EM algorithm can be
set as parameters passed to haplo.em.control. 
}
\usage{
haplo.em.control(loci.insert.order=NULL, insert.batch.size = 6,
                             min.posterior = 1e-07, tol = 1e-05,
                             max.iter=500, random.start=0, n.try = 10,
                             iseed=NULL, max.haps.limit = 2e6, verbose=0)
}
\arguments{

\item{loci.insert.order }{
Numeric vector with specific order to insert the loci. If this value
is NULL, the insert oder will be in sequential order (1, 2, ..., No. Loci).
}
\item{insert.batch.size }{
Number of loci to be inserted in a single batch.
}
\item{min.posterior }{
Minimum posterior probability of haplotype pair, conditional on
observed marker genotypes. Posteriors below this minimum value will
have their pair of haplotypes "trimmed" off the list of possible
pairs.
}
\item{tol}{
Default 1e-5
}
\item{max.iter }{
Maximum number of iterations allowed for the EM algorithm before it
stops and prints an error.  Default is 500.  
}
\item{random.start }{
If random.start = 0, then the inititial starting values of the
posteriors for the first  EM attempt will be based on assuming equal
posterior probabilities (conditional on genotypes). If random.start = 1,
then the initial starting values of the first  EM attempt will be based on assuming a uniform distribution for
the initial posterior probabilities.
}
\item{n.try }{
Number of times to try to maximize the lnlike by the EM algorithm. The
first try will use, as initial starting values for the posteriors,
either equal values or uniform random variables, as determined by
random.start. All subsequent tries will use uniform random values as
initial starting values for the posterior probabilities.
}
\item{iseed}{
An integer or a saved copy of .Random.seed. This allows simulations to
be reproduced by using the same initial seed.
}
\item{max.haps.limit }{
The maximum number of haplotypes for which memory is allocated. 
}
\item{verbose}{
Logical, if [T]rue, print lots of debug messages to the screen.  If [F]alse, default,
do not print any messages. It is best to use verbose=F.
}
}
\value{
A list of the parameters passed to the function.
}
\section{Side Effects}{

}
\details{
The default is to use n.try = 10. If this takes too much time, it may
be worthwhile to decrease n.try. Other tips for computing haplotype
frequencies for a large number of loci, particularly if some have many
alleles, is to decrease the batch size (insert.batch.size), increase
the memory (max.haps.limit).
}
\section{References}{

}
\seealso{
\code{\link{haplo.em}},
\code{\link{haplo.score}}
}
\examples{
# This is how it is used within haplo.score
#    > score.gauss <- haplo.score(resp, geno, trait.type="gaussian", 
#    >           em.control=haplo.em.control(insert.batch.size = 2, n.try=1))
}
\keyword{}
% docclass is function
% Converted by Sd2Rd version 1.21.

\eof
\name{haplo.em.fitter}
\alias{haplo.em.fitter}
\title{
  Compute engine for haplotype EM algorithm 
}
\description{
For internal use within the haplo.stats library
}
\usage{
haplo.em.fitter(n.loci, n.subject, weight, geno.vec, n.alleles,
                max.haps, max.iter, loci.insert.order, min.posterior, 
                tol, insert.batch.size, random.start, iseed1, iseed2, 
                iseed3, verbose)
}
\arguments{

\item{n.loci }{

}
\item{n.subject }{

}
\item{weight}{

}
\item{geno.vec }{

}
\item{n.alleles }{

}
\item{max.haps }{

}
\item{max.iter }{

}
\item{loci.insert.order }{

}
\item{min.posterior }{

}
\item{tol}{

}
\item{insert.batch.size }{

}
\item{random.start }{

}
\item{iseed1}{

}
\item{iseed2}{

}
\item{iseed3}{

}
\item{verbose}{

}
}
\value{
}
\section{Side Effects}{

}
\details{
For internal use within the haplo.stats library
}
\section{References}{

}
\seealso{

}
\examples{

}
\keyword{}
% docclass is function
% Converted by Sd2Rd version 1.21.

\eof
\name{haplo.enum}
\alias{haplo.enum}
\title{
  Enumerate all possible pairs of haplotypes that are consistent with 
a set of un-phased multilocus markers
}
\description{
Given subject un-phased genotype hmat, enumerate all possible pairs 
of haplotypes, and return enumerated pairs in matrices h1 and h2.
}
\usage{
haplo.enum(hmat)
}
\arguments{

\item{hmat}{
A genotype vector of length 2*K (K = number of loci).  When used in 
haplo.em, it is a single row of a genotype matrix.
}
}
\value{
List with components:

\item{h1}{
A matrix of enumerated haplotypes.  If there are N
enumerations, h1 will have dimension N x K.
}
\item{h2}{
Similar to h1, a matrix of enumerated haplotypes for the second 
members of the pairs of haplotypes.  Haplotype pairs in h1 and h2
match by the same row number.
}
}
\section{Side Effects}{

}
\details{
For a pair of haplotypes, if there are H sites that are
heterozygous, then there are 2 raised to (H-1) possible pairs to
enumerate. To achieve this, the algorithm moves across the
loci that are heterozygous  (after the 1st heterozygous
locus), flipping alleles at heterozygous locations to
enumerate all possible pairs of haplotpes, and appending
results as rows of the output matrices h1, and h2.
}
\section{References}{

}
\seealso{
\code{\link{haplo.em}}
}
\examples{

}
\keyword{}
% docclass is function
% Converted by Sd2Rd version 1.21.

\eof
\name{haplo.glm}
\alias{haplo.glm}
\title{
  GLM Regression of Trait on Ambiguous Haplotypes
}
\description{
Perform glm regression of a trait on haplotype effects, allowing for
ambiguous haplotypes. This method performs an iterative  two-step EM, 
with the posterior probabilities of pairs of haplotypes per subject used as
weights to update the regression coefficients, and the regression
coefficients used to update the posterior probabilities.
}
\usage{
haplo.glm(formula=formula(data), family=gaussian, data=sys.parent(),
           weights, na.action="na.geno.keep", start=eta, miss.val=c(0,NA),
           locus.label=NA, allele.lev=NULL, control=haplo.glm.control(), 
           method="glm.fit", model=FALSE, x=FALSE, y=TRUE, 
           contrasts=NULL, ...)
}
\arguments{
\item{formula}{
          a formula expression as for other regression models, of the
          form response ~ predictors. For details, see the documentation
          for lm and formula. 
}
\item{family}{
          a family object. This is a list of expressions for defining the
          link, variance function, initialization values, and iterative
          weights for the generalized linear model. Supported families
          are: gaussian, binomial, poisson. Currently, only the logit
          link is implemented for binimial.        
}
\item{data}{
  a data frame in which to interpret the variables occurring in
  the formula. A CRITICAL element of the data frame is the
  matrix of genotypes, denoted here as "geno", although an 
  informative name should be used in practice. This geno matrix is actually a 
  matrix of alleles, such that each locus has a pair of adjacent 
  columns of alleles, and the order of columns corresponds to 
  the order of loci on a chromosome.  If there are K loci, then 
  ncol(geno) = 2*K. Rows represent the alleles for each subject. It is
  also CRITICAL that this matrix is defined as a model.matrix, in order
  to keep the columns of the matrix packaged together into the single
  matrix object. If geno is a matrix of alleles, then before adding it to
  the data frame, use the following command to convert it to a
  model.matrix:  oldClass(geno) <- "model.matrix". If geno is a data.frame of
  alleles, you must first convert geno to a matrix, using geno <-
  as.matrix(geno), and then convert it to a model.matrix.
}
\item{weights}{
  the weights for observations (rows of the data frame). By default, all
  observations are weighted equally.
}
\item{na.action }{
  a function to filter missing data. This is applied to the
  model.frame. The default value of na.action=na.geno.keep will keep
  observations with missing alleles, but exclude observations missing
  any other data (e.g., response variable, other covariates,
  weight). The EM algorithm for ambiguous haplotypes accounts
  for missing alleles. Similar to the usual glm, na.fail creates an error if any
  missing values are found, and a third possible alternative is na.exclude,
  which deletes observations that contain one or more missing
  values for any data, including alleles.
}
\item{start}{
  a vector of initial values on the scale of the linear
  predictor.
}
\item{miss.val }{
  vector of values that represent missing alleles in geno matrix.
}
\item{locus.label }{
  vector of labels for loci.
}
\item{allele.lev }{
This argument is optional ONLY for S-PLUS, but is REQUIRED for
R. This is a list of vectors, each vector giving the labels of alleles
for each locus. The list is made an attribute of geno<-setupGeno(geno). This is
required to account for the differences in which S-PLUS and R handle
character data (allele labels) in a model.frame.  See its use in the example
below.
}
\item{control}{
  list of control parameters. The default is constructed by the function
  haplo.glm.control. The items in this list control the regression
  modeling of the haplotypes (e.g., additive, dominant, recessive
  effects of haplotypes; which haplotype is chosen as the baseline for
  regression; how to handle rare haplotypes; control of the glm function
  - maximum number of iterations), and the EM algorithm for estimating initial
  haplotype frequencies. See haplo.glm.control for details.
}
\item{method}{
  currently, glm.fit is the only method allowed.
}
\item{model}{
  if model=TRUE, the model.frame is returned.
}
\item{x}{
  a logical flag. If x=TRUE, the model.matrix is returned. By
  default, x=FALSE.
}
\item{y}{
 
  a logical flag. The default value of y=TRUE causes the response
  variable to be returned.
}
\item{contrasts}{
  currently, contrasts is ignnored (so NULL, the default value, is
  always used).
}
\item{\dots }{
  potential other arguments that may be passed - currently ignored.
}
}
\value{
  An object of class "haplo.glm" is returned.          
  The output object from haplo.glm has all the components of a
  glm object, with a few more. It is important to note that some of the returned
  components correpond to the "expanded" version of the data. This 
  means that each observation is expanded into the number of terms in the
  observation's posterior distribution of haplotype pairs, given the
  marker data. For example, when fitting the response y on haplotype
  effects, the value of y[i], for the ith observation, is replicated
  m[i] times, where m[i] is the number of pairs of haplotypes consistent
  with the observed marker data. The returned components that are
  expanded are indicated below by [expanded] in the definition of the component.
  These expanded components may need to be collapsed, depending on the
  user's objectives. For example, when considering the influence of 
  an observation, it may make sense to examine the expanded residuals
  for a single observation, perhaps plotted against the haplotypes
  for that observation. In contrast, it would not be sensible to plot
  all residuals against non-genetic covaraites, without first
  collapsing the expanded residuals for each observation. To collapse,
  one can use the average residual per observation, weighted according
  to the posterior probabilities. The appropriate weight can be
  computed as wt = fit\$weight.expanded * fit\$haplo.post.info\$post.
  Then, the weighted average can be calculated as
  tapply(fit\$residuals * wt, fit\$haplo.post.info\$indx, sum).

\item{coefficients}{
the coefficients of the linear.predictors, which multiply the
  columns of the model matrix. The names of the coefficients are
  the names of the columns
  of the model matrix. For haplotype coefficients, the names
  are the concatentation of name of the geno matrix with a haplotype
  number. The haplotype number corresponds to the index of the
  haplotype. The default print will show the coefficients with haplotype
  number, along with the alleles that define the haplotype, and the
  estimated haplotype frequency. If the model is over-determined there
  will be missing values in the coefficients corresponding to
  inestimable coefficients.
}
\item{residuals}{
[expanded]  residuals from the final weighted least squares fit; also
  known as working residuals, these are typically not
  interpretable without rescaling by the weights (see glm.object).
}
\item{fitted.values}{
[expanded] fitted mean values, obtained by transforming
  linear.predictors using the inverse link function (see glm.object).
}
\item{effects}{
[expaded] orthogonal, single-degree-of-freedom effects (see lm.object).          
}
\item{R}{
the triangular factor of the decomposition (see lm.object).                
}
\item{rank}{
the computed rank (number of linearly independent columns in
  the model matrix), which is the model degrees of freedom - see lm.object.
}
\item{assign}{
the list of assignments of coefficients (and effects) to the
  terms in the model (see lm.object).      
}
\item{df.residual}{
[expanded] number of degrees of freedom for residuals, corresponding
  to the expanded data.
}
\item{weights.expanded}{
[expanded] input weights after expanding according to the number
  of pairs of haplotypes consistent with an observation's 
  marker genotype data. 
}
\item{family}{
a 3 element character vector giving the name of the family, the
 link and the variance function; mainly for printing purposes.           
}
\item{linear.predictors}{
[expanded] linear fit, given by the product of the model matrix and
  the coefficients; also the fitted.values from the final
  weighted least squares fit.
}
\item{deviance}{
[expanded] up to a constant, minus twice the maximized log-likelihood.
 Similar to the residual sum of squares.         
}
\item{null.deviance}{
the deviance corresponding to the model with no predictors.    
}
\item{call}{
an image of the call that produced the object, but with the
   arguments all named and with the actual formula included as the
   formula argument.             
}
\item{iter}{
the number of IRLS iterations used to compute the estimates, for the
  last step of the EM fit of coefficients.
}
\item{y}{
[expanded] response, if y=T.                
}
\item{contrasts}{
a list containing sufficient information to construct the
  contrasts used to fit any factors occurring in the model (see lm.object).        
}
\item{lnlike}{
log-likelihood of the fitted model.     
}
\item{lnlike.null}{
log-likelihood of the null model that has only an intercept.      
}
\item{lrt}{
likelihood ratio test statistic to test whether all coefficients
  (excepet intercept) are zero: 2*(lnlike - lnlike.null)
}
\item{terms}{
an object of mode expression and class term summarizing the
  formula, but not complete for the final model. Because this does
  not represent expansion of the design matrix for the haplotypes, it
  is typically not of direct relevance to users.           
}
\item{control}{
list of all control parameters        
}
\item{haplo.unique}{
the data.frame of unique haplotypes   
}
\item{haplo.base}{
the index of the haplotype used as the base-line for the regression
  model. To see the actual haplotype definition, use the following: 
  fit\$haplo.unique[fit\$haplo.base,], where fit is the saved haplo.glm
  object (e.g., fit <- haplo.glm(y ~ geno, ...) ).
}
\item{haplo.freq}{
the final estimates of haplotype frequencies, after completing EM
  steps of updating haplotype frequencies and regression coefficients.
  The length of haplo.freq is the number of rows of haplo.unique, and
  the order of haplo.freq is the same as that for the rows of
  haplo.unique. So, the frequencies of the unique haplotypes can be 
  viewed as cbind(fit\$haplo.unique, fit\$haplo.freq).
}
\item{haplo.freq.init}{
the initial estimates of haplotype frequencies, based on the EM
  algorithm for estimating haplotype frequencies, ingnoring the
  trait. These can be compared with haplo.freq, to see the impact of 
  using the regression model to update the haplotype frequencies.
}
\item{converge.em}{
T/F whether the initial EM algorithm for estimating haplo.freq.init
  converged.
}
\item{haplo.common}{
the indices of the haplotypes determined to be "common" enough to
  estimate their corresponding regression coefficients.
}
\item{haplo.rare}{
the indices of all the haplotypes determined to be too rare to
  estimate their specific regression coefficients.     
}
\item{haplo.rare.term}{
T/F whether the "rare" term is included in the haplotype regression model.
}
\item{haplo.names}{
the names of the coefficients that represent haplotype effects.    
}
\item{haplo.post.info}{
a data.frame of information regarding the posterior
  probabilites. The columns of this data.frame are: indx (the index of
  the input obsevation; if the ith observation is repeated m times, then
  indx will show m replicates of i; hence, indx will correspond to the
  "expanded" observations); hap1 and hap2 (the indices of the
  haplotypes; if hap1=j and hap2=k, then the two haplotypes in terms
  of alleles are fit\$haplo.unique[j,] and fit\$haplo.unique[k,]);
  post.init (the initial posterior probability, based on
  haplo.freq.init); post (the final posterior probability, based on
  haplo.freq).
}
\item{x}{
the model matrix, with [expanded] rows, if x=T.              
}
\item{info}{
the observed information matrix, based on Louis' formula. The upper
  left submatrix is for the regression coefficient, the lower right
  submatrix for the haplotype frequencies, and the remaining is the
  information between regression coefficients and haplotype frequencies. 
}
\item{var.mat}{
the variance-covariance matrix of regression coefficients and
  haplotype frequencies, based on the inverse of info. Upper left
  submatrix is for regression coefficients, lower right submatrix for
  haplotype frequencies.
}
\item{haplo.elim}{
the indices of the haplotypes eliminated from the info and var.mat
  matrices because their frequencies are less than haplo.min.info (the
  minimum haplotype frequency required for computation of the
  information matrix - see haplo.glm.control)
}
\item{rank.info}{
rank of information (info) matrix.
}
}
\details{

}
\section{References}{
  Lake S, Lyon H, Silverman E, Weiss S, Laird N, Schaid D (2002)
  Estimation and tests of haplotype-environment interaction 
  when linkage phase is ambiguous. Human Heredity 55:56-65.
}
\seealso{
haplo.glm.control, haplo.em, haplo.model.frame
}
\examples{
 setupData(hla.demo)
 geno <- as.matrix(hla.demo[,c(17,18,21:24)])
 keep <- !apply(is.na(geno) | geno==0, 1, any)
 hla.demo <- hla.demo[keep,]
 geno <- geno[keep,]
 attach(hla.demo)
 label <-c("DQB","DRB","B")
 y <- hla.demo$resp
 y.bin <- 1*(hla.demo$resp.cat=="low")

# set up a genotype array as a model.matrix for inserting into data frame
# Note that hla.demo is a data.frame, and we need to subset to columns
# of interest. Also also need to convert to a matrix object, so that
# setupGeno can code alleles and convert geno to 'model.matrix' class.

 geno <- setupGeno(geno, miss.val=c(0,NA))

  # geno now has an attribute 'unique.alleles' which must be passed to
  # haplo.glm as allele.lev=attributes(geno)$unique.alleles, see below

 my.data <- data.frame(geno=geno, age=hla.demo$age, male=hla.demo$male,
                      y=y, y.bin=y.bin)

 fit.gaus <- haplo.glm(y ~ male + geno, family = gaussian,  na.action=
               "na.geno.keep",allele.lev=attributes(geno)$unique.alleles, 
               data=my.data, locus.label=label,
               control = haplo.glm.control(haplo.freq.min=0.02))
 fit.gaus
 
}
\keyword{}
% docclass is function
% Converted by Sd2Rd version 1.21.

\eof
\name{haplo.glm.control}
\alias{haplo.glm.control}
\title{
  Create list of control parameters for haplo.glm
}
\description{
Create a list of control pararameters for haplo.glm. If no parameters
are passed to this function, then all default values are used.
}
\usage{
haplo.glm.control(haplo.effect="add", haplo.base=NULL,haplo.freq.min=0.001, 
                  sum.rare.min=0.001, haplo.min.info=0.001, 
                  keep.rare.haplo=TRUE, glm.c=glm.control(maxit=500), 
                                                  em.c=haplo.em.control())
}
\arguments{
\item{haplo.effect }{
  the "effect" of a haplotypes, which determines the covariate (x)
  coding of haplotypes. Valid options are "additive" (causing x = 0,
  1, or 2, the count of a  particular haplotype), "dominant" (causing
 x = 1 if heterozygous or homozygous carrier of a particular
  haplotype; x = 0 otherwise), and "recessive" (causing x = 1 if
  homozygous for a particular haplotype; x = 0 otherwise).
}
\item{haplo.base }{
  the index for the haplotype to be used as the base-line for
  regression. By default, haplo.base=NULL, so that the most frequent
  haplotype is chosen as the base-line.
}
\item{haplo.freq.min }{
  the minimum haplotype frequency for a haplotype to be included in
  the regression model as its own effect. The haplotype frequency is
  based on the EM algorithm that estimates haplotype frequencies
  independent of trait.
}
\item{sum.rare.min }{
  the sum of the "rare" haplotype frequencies must be larger than
  sum.rare.min in order for the pool of rare haplotypes to be included
  in the regression model as a separate term. If this condition
  is not met, then the rare haplotypes are pooled with the base-line
  haplotype (see keep.rare.haplo below).
}
\item{haplo.min.info }{
  the minimum haplotype frequency for determining the contribution of 
  a haplotype to the observed
  information matrix. Haplotypes with less frequency are
  dropped from the observed information matrix. The haplotype
  frequency is that from the final EM that iteratively updates 
  haplotype frequencies and regression coefficients. 
}
\item{keep.rare.haplo }{
  TRUE/FALSE to determine if the pool of rare haplotype should be kept as a
  separate term in the regression model (when keep.rare.haplo=TRUE), or
  pooled with the base-line haplotype (when keep.rare.haplo=FALSE).
}
\item{glm.c }{
  list of control parameters for the usual glm.control (see
glm.control).
}
\item{em.c }{
  list of control parameters for the EM algorithm to estimate
  haplotype frequencies, independent of trait (see haplo.em.control). 
}
}
\value{
  the list of above components
}
\seealso{
  glm.control, haplo.em.control
}
\examples{
# using the data set up in the example for haplo.glm,
# the control function is used in haplo.glm as follows
#  > fit <- haplo.glm(y ~ male + geno, family = gaussian,  
#  >          na.action="na.geno.keep",
#  >          data=my.data, locus.label=locus.label,
#  >          control = haplo.glm.control(haplo.freq.min =
#  >          0.02,em.c=haplo.em.control(n.try=1)))
}
\keyword{}
% docclass is function
% Converted by Sd2Rd version 1.21.

\eof
\name{haplo.group}
\alias{haplo.group}
\title{
  Frequencies for Haplotypes by Grouping Variable
}
\description{
Calculate maximum likelihood estimates of haplotype probabilities for 
the entire dataset and separately for each subset defined by the
levels of a group variable.  Only autosomal loci are considered.
}
\usage{
haplo.group(group, geno, locus.label=NA, miss.val=0, 
            control=haplo.em.control())
}
\arguments{
\item{group}{
Group can be of logical, numeric, character, or factor class type.
}
\item{geno}{
Matrix of alleles, such that each locus has a pair of
adjacent columns of alleles, and the order of columns
corresponds to the order of loci on a chromosome.  If
there are K loci, then geno has 2*K columns. Rows represent all
observed alleles for each subject.  
}
\item{locus.label }{
Vector of labels for loci, of length K (see definition of geno matrix).
}
\item{miss.val }{
Vector of codes for allele missing values.
}
\item{control}{
list of control parameters for haplo.em (see haplo.em.control).
}
}
\value{

\item{ }{
A list as an object of the haplo.group class.  The three
elements of the list are described below.
}
\item{group.df}{
A data frame with the columns described as follows.
-haplotype:
Names for the K columns for the K alleles in the haplotypes.
-total:
Estimated frequencies for haplotypes from the total sample.
-group.name.i:
Estimated haplotype frequencies for the haplotype
if it occurs in the group referenced by 'i'.  Frequency is NA 
if it doesn't occur for the group.  The column name is the actual 
variable name joined with the ith level of that variable.
}
\item{group.count}{
Vector containing the number of subjects for each level of the 
grouping variable.
}
\item{n.loci}{
Number of loci occuring in the geno matrix.
}
}
\section{Side Effects}{

}
\details{
Haplo.em is used to compute the maximum likelihood estimates of 
the haplotype frequencies for the total sample, then for each of 
the groups separately.  
}
\section{References}{
Schaid DJ, Rowland CM, Tines DE, Jacobson RM,  Poland  GA.
"Score tests for association of traits with haplotypes when
linkage phase is ambiguous." Amer J Hum Genet. 70 (2002):  425-434.
}
\seealso{
print.haplo.group, haplo.em
}
\examples{
  setupData(hla.demo)
  geno <- as.matrix(hla.demo[,c(17,18,21:24)])

# remove any subjects with missing alleles for faster examples, 
# but you may keep them in practice
  keep <- !apply(is.na(geno) | geno==0, 1, any)
  hla.demo <- hla.demo[keep,]
  geno <- geno[keep,]
  attach(hla.demo)
  
  y.ord <- as.numeric(resp.cat)
  y.bin <-ifelse(y.ord==1,1,0)
  group.bin <- haplo.group(y.bin, geno, miss.val=0)
  print.haplo.group(group.bin)
}
\keyword{}
% docclass is function
% Converted by Sd2Rd version 1.21.

\eof
\name{haplo.hash}
\alias{haplo.hash}
\title{
  Integer Rank Codes for Haplotypes
}
\description{
Create a vector of integer codes for the input  matrix  of
haplotypes.   The haplotypes in the input matrix are
converted to character strings, and if there are C unique
strings, the integer codes for the haplotypes will be 1,
2, ..., C.
}
\usage{
haplo.hash(hap)
}
\arguments{

\item{hap}{
A matrix of haplotypes. If there are N haplotypes for K
loci, hap have dimensions N x K.
}
}
\value{
List with elements:

\item{hash}{
Vector of integer codes for the input data  (hap).  The
value of hash is the row number of the unique haplotypes
given in the returned matrix hap.mtx.
}
\item{hap.mtx}{
Matrix of unique haplotypes.
}
}
\section{Side Effects}{

}
\details{
The alleles that make  up  each  row  in  hap  are  pasted
together  as character strings, and the unique strings are
sorted so that the rank order of  the  sorted  strings  is
used as the integer code for the unique haplotypes.
}
\section{References}{

}
\seealso{
haplo.em
}
\examples{

}
\keyword{}
% docclass is function
% Converted by Sd2Rd version 1.21.

\eof
\name{haplo.model.frame}
\alias{haplo.model.frame}
\title{
  Sets up a model frame for haplo.glm
}
\description{
For internal use within the haplo.stats library
}
\usage{
haplo.model.frame(m, locus.label=NA, allele.lev=NULL, miss.val=c(0,NA), 
                  control=haplo.glm.control())
}
\arguments{

\item{m}{

}
\item{locus.label }{

}
\item{allele.lev }{

}
\item{miss.val }{

}
\item{control}{

}
}
\value{
}
\section{Side Effects}{

}
\details{

}
\section{References}{

}
\seealso{

}
\examples{

}
\keyword{}
% docclass is function
% Converted by Sd2Rd version 1.21.

\eof
\name{haplo.score}
\alias{haplo.score}
\title{
  Score Statistics for Association of Traits with Haplotypes
}
\description{
Compute score statistics to evaluate the association of a trait
with haplotypes, when linkage phase is unknown and diploid marker 
phenotypes are observed among unrelated subjects. For now, only 
autosomal loci are considered.  
}
\usage{
haplo.score(y, geno, trait.type="gaussian", offset = NA,
            x.adj = NA, skip.haplo=.005, locus.label=NA,
            miss.val=c(0,NA), simulate=FALSE, sim.control=score.sim.control(),
            em.control=haplo.em.control())
}
\arguments{
\item{y}{
Vector of trait values. For trait.type = "binomial", y must 
have values of 1 for event, 0 for no event.
}
\item{geno}{
Matrix of alleles, such that each locus has a pair of
adjacent columns of alleles, and the order of columns
corresponds to the order of loci on a chromosome.  If
there are K loci, then ncol(geno) = 2*K. Rows represent
alleles for each subject.
}
\item{trait.type }{
Character string defining type of trait, with values of 
"gaussian", "binomial", "poisson", "ordinal".
}
\item{offset}{
Vector of offset when trait.type = "poisson"
}
\item{x.adj }{
Matrix of non-genetic covariates used to adjust the score 
statistics.  Note that intercept should not be included, 
as it will be added in this function.
}
\item{skip.haplo }{
Skip score statistics for haplotypes with frequencies < skip.haplo
}
\item{locus.label }{
Vector of labels for loci, of length K (see definition of geno matrix)
}
\item{miss.val }{
Vector of codes for missing values of alleles
}
\item{simulate}{
Logical:  if [F]alse, no empirical p-values are computed; if [T]rue,
simulations are performed. Specific simulation parameters
can be controlled in the sim.control parameter list.  
}
\item{sim.control }{
A list of control parameters to determine how simulations are performed for simulated
p-values.  The list is created by the function
score.sim.control and the default values of this function can be
changed as desired.  See score.sim.control for details.
}
\item{em.control }{
A list of control parameters to determine how to perform the EM algorithm for
estimating haplotype frequencies when phase is unknown.  The list is
created by the function haplo.em.control - see this function for more details.
}
}
\value{
List with the following components:

\item{score.global}{
Global statistic to test association of trait with 
haplotypes that have frequencies >= skip.haplo.
}
\item{df}{
Degrees of freedom for score.global.
}
\item{score.global.p}{
P-value of score.global based on chi-square distribution, 
with degrees of freedom equal to df.
}
\item{score.global.p.sim}{
P-value of score.global based on simulations
(set equal to NA when simulate=F).
}
\item{score.haplo}{
Vector of score statistics for individual
haplotypes that have frequencies >= skip.haplo.
}
\item{score.haplo.p}{
Vector of p-values for score.haplo, based on a
chi-square distribution with 1 df.
}
\item{score.haplo.p.sim}{
Vector of p-values for score.haplo, based on
simulations (set equal to NA when simulate=F).
}
\item{score.max.p.sim}{
P-value  of  maximum  score.haplo, based on
simulations  (set equal to NA when simulate=F).
}
\item{haplotype}{
Matrix of hapoltypes  analyzed.  The ith row of
haplotype corresponds to the ith item of score.haplo,
score.haplo.p, and score.haplo.p.sim.
}
\item{hap.prob}{
Vector of haplotype probabilies, corresponding to the
haplotypes in the matrix haplotype.
}
\item{locus.label}{
Vector of labels for loci, of length  K  (same  as
input argument).
}
\item{simulate}{
Same as function input  parameter.  If [T]rue, simulation results are
included in the haplo.score object.
}
\item{n.val.global}{
Vector containing the number of valid simulations used in the
global score statistic simulation. The number of valid simulations can
be less than the number of simulations requested (by sim.control)
if simulated data sets produce unstable variances of the score
statistics.  
}
\item{n.val.haplo}{
Vector containing the number of valid simulations used in the p-value
simulations for maximum-score statistic and scores for the individual
haplotypes.
}
}
\section{Side Effects}{

}
\details{
Compute the maximum likelihood estimates of the haplotype frequencies
and the posterior probabilities of the pairs of haplotypes for each
subject using an EM algorithm. The algorithm begins with haplotypes
from a subset of the loci and progressively discards those with low
frequency before inserting more loci.  The process is repeated until
haplotypes for all loci are established.  The posterior probabilities
are used to compute the score statistics for the association of
(ambiguous) haplotypes with traits. The glm function is used to
compute residuals of the regression of the trait on the non-genetic
covariates.  
}
\section{References}{
Schaid DJ, Rowland CM, Tines DE, Jacobson RM,  Poland  GA.
"Score tests for association of traits with haplotypes when
linkage phase is ambiguous." Amer J Hum Genet. 70 (2002):  425-434.
}
\seealso{
\code{\link{haplo.em}},
\code{\link{plot.haplo.score}},
\code{\link{print.haplo.score}},
\code{\link{haplo.em.control}},
\code{\link{score.sim.control}}
}
\examples{
  # establish all hla.demo data, remove genotypes with missing alleles
  # so haplo.score runs faster

  setupData(hla.demo)
  geno <- as.matrix(hla.demo[,c(17,18,21:24)])
  keep <- !apply(is.na(geno) | geno==0, 1, any)
  hla.demo <- hla.demo[keep,]
  geno <- geno[keep,]
  attach(hla.demo)
  label <- c("DQB","DRB","B")
 
# For quantitative, normally distributed trait:

  score.gaus <- haplo.score(resp, geno, locus.label=label, 
                            trait.type = "gaussian")
  print(score.gaus)

# For ordinal trait:
  y.ord <- as.numeric(resp.cat)
  score.ord <- haplo.score(y.ord, geno, locus.label=label,
                           trait.type="ordinal")
  print(score.ord)

# For a  binary trait and simulations,
# limit simulations to 500 in score.sim.control, default is 20000
  y.bin <-ifelse(y.ord==1,1,0)
  score.bin.sim <- haplo.score(y.bin, geno, trait.type = "binomial",
                     locus.label=label, simulate=TRUE, sim.control=
                     score.sim.control(min.sim=200,max.sim=500))

  print(score.bin.sim)

# For a binary trait, adjusted for sex and age:

  x <- cbind(male, age)
  score.bin.adj <- haplo.score(y.bin, geno, trait.type = "binomial", 
                               locus.label=label, x.adj=x)
  print(score.bin.adj)
}
\keyword{}
% docclass is function
% Converted by Sd2Rd version 1.21.

\eof
\name{haplo.score.glm}
\alias{haplo.score.glm}
\title{
  Compute haplotype score statistics for GLM
}
\description{
This function is used by haplo.score when analyzing traits
by a GLM score.
}
\usage{
haplo.score.glm(y, mu, a, v, x.adj, nreps, x.post, post, x)
}
\arguments{
\item{y}{
Vector of trait values.
}
\item{mu}{
Expected value of y.
}
\item{a}{
scale parameter
}
\item{v}{
v= b''/a for a GLM.
}
\item{x.adj }{
Matrix of non-genetic covariates used  to  adjust  the
score  statistics. Note that intercept should  be included
in this matrix.
}
\item{nreps}{
Vector for the count of haplotype  pairs  that  map  to
each subject's marker genotypes (see haplo.em).
}
\item{x.post }{
Matrix for posterior mean of x per subject.
}
\item{post}{
Vector of posterior probabilities of pairs of
haplotypes for a person, given thier marker phenotypes
(see haplo.em).
}
\item{x}{
Matrix  of  scores  for  enumerated  haplotypes  for  each
subject,  with  elements  0,  1,  2  (counts  of  specific
haplotypes).
}
None.
}
\value{
List with components:

\item{u.score}{
Vector of scores for the chosen haplotypes
}
\item{v.score}{
Covariance matrix for u.score
}
}
\section{Side Effects}{

}
\details{
Using posterior probabilities of pairs of haplotypes,  the
"design" matrix for the haplotype effects, and the GLM
residuals, compute the score vector and its variance
matrix, adjusted for the non-genetic covariates.
}
\section{References}{
Schaid DJ, Rowland CM, Tines DE, Jacobson RM,  Poland  GA.
Score tests for association of traits with haplotypes when
linkage phase is ambiguous. Submitted to Amer J Hum Genet.
}
\seealso{
haplo.score
}
\examples{

}
\keyword{}
% docclass is functionhaplo
% Converted by Sd2Rd version 1.21.

\eof
\name{haplo.score.merge}
\alias{haplo.score.merge}
\title{
  Merge haplo.score And haplo.group Objects
}
\description{
Combine information from returned objects of haplo.score and 
haplo.group, 'score' and 'group' respectively.  'score' and
'group' are sorted differently and 'score' keeps a subset of 
all the haplotypes while 'group' has all of them.  To combine
results from the two objects, merge them by haplotype and sort 
by score of the haplotype. The merged object includes all haplotypes; 
i.e. those appearing in 'group', but the print default only shows 
haplotypes which have a score.
}
\usage{
haplo.score.merge(score, group)
}
\arguments{
\item{score}{
Object returned from haplo.score of class "haplo.score". 
}
\item{group}{
Object returned from haplo.group of class "haplo.group".
}
}
\value{
Data frame including haplotypes, score-statistics, score p-value, 
estimated haplotype frequency for all subjects, and haplotype 
frequency from group subsets.
}
\section{Side Effects}{
Warning:  The merge will not detect if the group and score objects
resulted from different subject phenotypes selected by memory-usage
parameters, rm.geno.na and enum.limit.  Users must use the same values
for these parameters in haplo.score and haplo.group so the merged
objects are consistent.
}
\details{
Haplo.score returns score statistic and p-value for haplotypes with
an overall frequency above the user-specified threshold, skip.haplo.  
For haplotypes with frequencies below the threshold, the score and 
p-value will be NA.  Overall haplotype frequencies and for sub-groups
are estimated by haplo.group.    
}
\seealso{
\code{\link{haplo.score}},
\code{\link{haplo.group}}
}
\examples{
  setupData(hla.demo)
  geno <- as.matrix(hla.demo[,c(17,18,21:24)])
  keep <- !apply(is.na(geno) | geno==0, 1, any)
  hla.demo <- hla.demo[keep,]
  geno <- geno[keep,]
  attach(hla.demo)
  y.ord <- as.numeric(resp.cat)
  y.bin <-ifelse(y.ord==1,1,0)
  
  group.bin <- haplo.group(y.bin, geno, miss.val=0)
  score.bin <- haplo.score(y.bin, geno, trait.type="binomial")
  score.merged <- haplo.score.merge(score.bin, group.bin)

  print(score.merged)
}
\keyword{}
% docclass is function
% Converted by Sd2Rd version 1.21.

\eof
\name{haplo.score.podds}
\alias{haplo.score.podds}
\title{
  Compute Haplotype Score Statistics for Ordinal Traits with
Proportional Odds Model
}
\description{
This function is used by haplo.score when analyzing ordinal traits
by a proportional odds model score statistic.
}
\usage{
haplo.score.podds(y, alpha, beta=NA, x.adj=NA, nreps, x.post, post, x)
}
\arguments{
\item{y}{
Vector of ordinal trait values.
}
\item{alpha}{
Intercept parameters for ordinal logistic regression model.
}
\item{beta}{
Regression parameters for adjusted covariates (x.adj).
}
\item{x.adj }{
Matrix of non-genetic covariates used  to  adjust  the
score  statistics. Note that intercept should NOT  be included
in this matrix.
}
\item{nreps}{
Vector for the count of haplotype  pairs  that  map  to
each subject's marker genotypes (see haplo.em).
}
\item{x.post }{
Matrix for posterior mean of x per subject.
}
\item{post}{
Vector of posterior probabilities of pairs of
haplotypes for a person, given thier marker phenotypes
(see haplo.em).
}
\item{x}{
Matrix  of  scores  for  enumerated  haplotypes  for  each
subject,  with  elements  0,  1,  2  (counts  of  specific
haplotypes).
}
None.
}
\value{
List with components:

\item{u.score}{
Vector of scores for the chosen haplotypes
}
\item{v.score}{
Covariance matrix for u.score
}
}
\section{Side Effects}{

}
\details{
Using posterior probabilities of pairs of haplotypes,  the
"design" matrix for the haplotype effects, and the proportional odds model, compute the score vector and its variance
matrix, adjusted for the non-genetic covariates.
}
\section{Warning}{
To analyze an  ordinal trait with adjustment for x.adj
covariates, the user will need to have Frank Harrell's librarys
(Design and Hmisc). However, the unadjusted ordinal trait  works fine
without these libraries.
}
\section{References}{
Schaid DJ, Rowland CM, Tines DE, Jacobson RM,  Poland  GA.
Score tests for association of traits with haplotypes when
linkage phase is ambiguous. Submitted to Amer J Hum Genet.
}
\seealso{
haplo.score
}
\examples{

}
\keyword{}
% docclass is function
% Converted by Sd2Rd version 1.21.

\eof
\name{haplo.score.slide}
\alias{haplo.score.slide}
\title{
  Score Statistics for Association of Traits with Haplotypes
}
\description{
Used to identify sub-haplotypes from a group of loci.  Run haplo.score
on all contiguous subsets of size n.slide from the loci in a genotype
matrix (geno).  From each call to haplo.score, report the global score
statistic p-value. Can also report global and maximum score statistics
simulated p-values.
}
\usage{
haplo.score.slide(y, geno, trait.type="gaussian", n.slide=2,
                  offset = NA, x.adj = NA, skip.haplo=.005,
                  locus.label=NA, miss.val=c(0,NA),
                  simulate=FALSE, sim.control=score.sim.control(),
                  em.control=haplo.em.control())
}
\arguments{
\item{y}{
Vector of trait values. For trait.type = "binomial", y must 
have values of 1 for event, 0 for no event.
}
\item{geno}{
Matrix of alleles, such that each locus has a pair of
adjacent columns of alleles, and the order of columns
corresponds to the order of loci on a chromosome.  If
there are K loci, then ncol(geno) = 2*K. Rows represent
alleles for each subject.
}
\item{trait.type }{
Character string defining type of trait, with values of 
"gaussian", "binomial", "poisson", "ordinal".
}
\item{n.slide }{
Number of loci in each contiguous subset.  The first subset is the ordered
loci numbered 1 to n.slide, the second subset is 2 through n.slide+1
and so on.  If the total number of loci in geno is n.loci, then there
are n.loci - n.slide + 1 total subsets.
}
\item{offset}{
Vector of offset when trait.type = "poisson"
}
\item{x.adj }{
Matrix of non-genetic covariates used to adjust the score 
statistics.  Note that intercept should not be included, 
as it will be added in this function. 
}
\item{skip.haplo }{
Skip score statistics for haplotypes with frequencies < skip.haplo
}
\item{locus.label }{
Vector of labels for loci, of length K (see definition of geno matrix).
}
\item{miss.val }{
Vector of codes for missing values of alleles.
}
\item{simulate}{
Logical, if [F]alse (default) no empirical p-values are computed.
If [T]rue simulations are performed.  Specific simulation parameters
can be controlled in the sim.control parameter list.
}
\item{sim.control }{
A list of control parameters used to perform simulations for simulated
p-values in haplo.score.  The list is created by the function
score.sim.control and the default values of this function can be
changed as desired.
}
\item{em.control }{
A list of control parameters used to perform the em algorithm for
estimating haplotype frequencies when phase is unknown.  The list is
created by the function haplo.em.control and the default values of
this function can be changed as desired.
}
}
\value{
List with the following components:

\item{df}{
Data frame with start locus, global p-value, simulated global p-value,
and simulated maximum-score p-value.
}
\item{n.loci}{
Number of loci given in the genotype matrix.
}
\item{simulate}{
Same as parameter description above.
}
\item{n.slide}{
Same as parameter description above.
}
\item{locus.label}{
Same as parameter description above.
}
\item{n.val.haplo}{
Vector containing the number of valid simulations used in the
maximum-score statistic p-value simulation.  The number of valid simulations
can be less than the number of simulations requested (by sim.control)
if simulated data sets produce unstable variables of the score
statistics. 
}
\item{n.val.global}{
Vector containing the number of valid simulations used in the
global score statistic p-value simulation.  
}
}
\section{Side Effects}{

}
\details{
Haplo.score.slide is useful for a series of loci where little is
known of the association between a trait and haplotypes.  Using a
range of n.slide values, the region with the strongest association
will consistently have low p-values for locus subsets containing the
associated haplotypes.  The global p-value measures significance 
of the entire set of haplotypes for the locus subset.  Simulated
maximum score statistic p-values indicate when one or a few haplotypes
are associated with the trait.
}
\section{References}{
Schaid DJ, Rowland CM, Tines DE, Jacobson RM,  Poland  GA.
"Score tests for association of traits with haplotypes when
linkage phase is ambiguous." Amer J Hum Genet. 70 (2002):  425-434.
}
\seealso{
\code{\link{haplo.score}},
\code{\link{plot.haplo.score.slide}},
\code{\link{score.sim.control}}
}
\examples{
  setupData(hla.demo)

# Continuous trait slide by 2 loci on all 11 loci, uncomment to run it.
# Takes > 20 minutes to run
#  geno.11 <- hla.demo[,-c(1:4)]
#  label.11 <- c("DPB","DPA","DMA","DMB","TAP1","TAP2","DQB","DQA","DRB","B","A")
#  slide.gaus <- haplo.score.slide(resp, geno.11, trait.type = "gaussian",
#                                  locus.label=label.11, n.slide=2)

#  print(slide.gaus)
#  plot(slide.gaus)

# Run shortened example on 9 loci 
# For an ordinal trait, slide by 3 loci, and simulate p-values:
  geno.9 <- hla.demo[,-c(1:6,15,16)]
  label.9 <- c("DPA","DMA","DMB","TAP1","DQB","DQA","DRB","B","A")
 
  y.ord <- as.numeric(hla.demo$resp.cat)

# data is set up, to run, run these lines of code on the data that was
# set up in this example. It takes > 15 minutes to run
#  slide.ord.sim <-  haplo.score.slide(y.ord, geno.9, trait.type = "ordinal",
#                      n.slide=3, locus.label=label.9, simulate=TRUE,
#                      sim.control=score.sim.control(min.sim=200, max.sim=500))

  # note, results will vary due to simulations
#  print(slide.ord.sim)
#  plot(slide.ord.sim)
#  plot(slide.ord.sim, pval="global.sim")
#  plot(slide.ord.sim, pval="max.sim")
}
\keyword{}
% docclass is function
% Converted by Sd2Rd version 1.21.

\eof
%  $Author: sinnwell $ 
%  $Date: 2004/03/12 21:51:18 $ 
%  $Header: /people/biostat3/sinnwell/Rdir/Make/RCS/hla.demo.Rd,v 1.3 2004/03/12 21:51:18 sinnwell Exp $
%  $Locker:  $ 


\name{hla.demo}
\alias{hla.demo}
\title{
  HLA Loci and Serologic Response to Measles Vaccination.
}
\description{
  Eleven HLA-region loci genotyped for 220 subjects, phase not
  known. Contains measles vaccination response with covariate data.
}
\usage{
data(hla.demo)
}
\format{
\item{ }{
Data Frame with the following columns:
}
\item{ resp }{
Quantitative response to Measles Vaccination 
}
\item{ resp.cat }{
Category of response as low, normal, or high; based on 'resp'
}
\item{ male }{
Binary indicator of gender, 1=male, 0=female
}
\item{ age }{
Age of the subject
}
\item{ allele columns 5 - 26 }{
  Pairs of columns represent the allele pairs for each subject at the
  locus.
}
}

\source{
  Data set kindly provided by Gregory A. Poland, M.D. and the Mayo
  Clinic Vaccine Research Group for illustration only, and my not be
  used for publication.
}
\section{References}{
  Schaid DJ, Rowland CM, Tines DE, Jacobson RM,  Poland  GA.
  "Score tests for association of traits with haplotypes when
  linkage phase is ambiguous." Amer J Hum Genet. 70 (2002):  425-434.
}

\keyword{datasets}
% docclass is function

\eof
\name{locator.haplo}
\alias{locator.haplo}
\title{
  Find Location from Mouse Clicks and Print Haplotypes on Plot
}
\description{
Much like the Splus locator() is used to find x-y coordinates on a plot,
locator.haplo() finds all x-y coordinates that are clicked on by a
user, and then prints haplotypes at the chosen positions.
}
\usage{
locator.haplo(obj)
}
\arguments{
\item{obj}{
An object (of class haplo.score) which contains the analysis results
that are returned from the function haplo.score.
}
}
\value{
List with the following components:

\item{x.coord}{
Vector of x-coordinates.
}
\item{y.coord}{
Vector of y-coordinates.
}
\item{hap.txt}{
Vector of character strings for haplotypes.
}
}
\details{
After plotting the results in obj, as from plot(obj), the function
locator.haplo is used to place on the plot the text strings for
haplotypes of interest. After the function call (e.g.,
locator.haplo(obj)), the user can click, with the left mouse button,
on as many points in the plot as desired. Then, clicking with the
middle mouse button will cause the haplotypes to be printed on the
plot. The format of a haplotype is "a:b:c", where a, b, and c are
alleles, and the separator ":" is used to separate alleles on a
haplotype. The algorithm chooses the closest point that the user
clicks on, and prints the haplotype either above the point (for points
on the lower-half of the plot) or below the point (for points in the
upper-half of the plot).
}
\seealso{
haplo.score
}
\examples{
# follow the pseudo-code
#  score.out <-  haplo.score(y, geno, trait.type = "gaussian")

#  plot(score.out)

#  locator.haplo(score.out)
}
\keyword{}
% docclass is function
% Converted by Sd2Rd version 1.21.

\eof
\name{loci}
\alias{loci}
\title{
  Create a group of locus objects from a genotype matrix, assign to
'model.matrix' class.  
}
\description{
The function makes each pair of columns a locus object, which
recodes alleles to numeric and saves the original alleles as an
attribute of the model.matrix. 
}
\usage{
loci(geno, locus.names, chrom.label=NULL, x.linked=FALSE, sex=NULL, 
     male.code="M", female.code="F", miss.val=NA, map=NA)
}
\arguments{
\item{geno}{
Matrix of alleles, such that each locus has a pair of adjacent
columns of alleles, and the order of columns corresponds to the
order of loci on a chromosome. If there are K loci, then
ncol(geno) = 2*K. Rows represent alleles for each subject.
}
\item{locus.names }{
A vector containing the locus name for each locus.
}
\item{chrom.label }{
Chromosome Label 
}
\item{x.linked }{
A logical value denoting whether the chromosome is X-linked.
}
\item{sex}{
A vector containing the sex of each individual. If x.linked=F then argum
ent sex is not required and may be left as the default value of NULL.
}
\item{male.code }{
The code denoting a male in the sex vector.
}
\item{female.code }{
The code denoting a female in the sex vector.
}
\item{miss.val }{
A vector of codes denoting missing values for the allele labels.  
Note that NA will always be treated as a missing value, and alleles
matching miss.val are assigned NA.  Also note that the original
missing value code for a specific individual can not be retrieved 
from the returned object.
}
\item{map}{
An optional chromosome map of class "cmap"
}
}
\value{
An object of class "model.matrix", with all alleles recoded to a
numeric value.  It contains the following attributes:

\item{locus.names}{
A vector of labels for the loci, of length nloci.
}
\item{map}{
Will be better defined later.
}
\item{x.linked}{
A logical value denoting whether the chromosome is X-linked.
}
\item{unique.alleles}{
The original allele labels are stored in the 'unique.alleles' attribute.
The ith item of the unique.alleles list is a vector of unique alleles
for the ith locus.
}
\item{male.code}{
The code denoting a male in the sex vector.
}
\item{female.code}{
The code denoting a female in the sex vector.
}
\item{chrom.label}{
Chromosome Label
}
}
\section{Side Effects}{

}
\details{

}
\section{References}{

}
\note{
A matrix that contains all elements of mode character will be sorted
in alphabetic order.
}
\seealso{
locus, setupGeno
}
\examples{
# Create some loci to work with
a1 <- 1:6
a2 <- 7:12

b1 <- c("A","A","B","C","E","D")
b2 <-c("A","A","C","E","F","G")

c1 <- c("101","10","115","132","21","112")
c2 <- c("100","101","0","100","21","110")

myloci <- data.frame(a1,a2,b1,b2,c1,c2)
myloci <- loci(myloci, locus.names=c("A","B","C"),miss.val=c(0,NA))
myloci

attributes(myloci)
}
\keyword{}
% docclass is function
% Converted by Sd2Rd version 1.21.

\eof
\name{locus}
\alias{locus}
\title{
  Creates an object of class "locus"
}
\description{
Creates an object containing genotypes for multiple individuals. The object can then use method functions developed for
objects of class "locus".
}
\usage{
locus(allele1, allele2, chrom.label=NULL,locus.alias=NULL,
     x.linked=FALSE, sex=NULL, male.code="M", female.code="F", miss.val=NA)
}
\arguments{
\item{allele1}{
A vector containing the labels for 1 allele for a set of individuals, or optionally a matrix with 2 columns each containing an allele for each person.
}
\item{allele2}{
A vector containing the labels for the second allele for a set of individuals.  If allele 1 is a matrix, allele 2 need not be specified.
}
\item{chrom.label }{
A label describing the chromosome the alleles belong to
}
\item{locus.alias }{
A vector containing one or more aliases describing the locus. The
first alias in the vector will be used as a label for printing in
some functions such as multilocus.print().  
}
\item{x.linked }{
A logical value denoting whether the chromosome is x linked
}
\item{sex}{
A vector containing the gender of each individual (required if x.linked=T)
}
\item{male.code }{
The code denoting a male in the sex vector
}
\item{female.code }{
The code denoting a female in the sex vector
}
\item{miss.val }{
a vector of codes denoting missing values for allele1 and
allele2. Note that NA will always be treated as a missing value, even
if not specified in miss.val.  Also note that if multiple missing
value codes are specified, the original missing value code for a
specific individual can not be retrieved from the locus object. 
}
}
\value{
Returns an object of class locus which inherits from class model.matrix containing the following elements:

\item{geno}{
a matrix with 2 columns where each row contains numeric codes for the 2 alleles for an individual.
}
\item{chrom.label}{
a chromosome label
}
\item{locus.alias}{
a vector of aliases for the locus
}
\item{x.linked}{
a logical value specifying if the locus is x-linked or not
}
\item{allele.labels}{
a vector of labels corresponding to the numeric codes in matrix geno (similar to levels in a factor)
}
\item{male.code}{
a code to be used to identify males for an x.linked locus.
}
\item{female.code}{
a code to be used to identify females for an x.linked locus.
}
}
\section{Side Effects}{

}
\details{

}
\section{References}{

}
\seealso{

}
\examples{
b1 <- c("A","A","B","C","E","D")
b2 <- c("A","A","C","E","F","G")
loc1 <- locus(b1,b2,chrom=4,locus.alias="D4S1111")

loc1

# a second example which uses more parameters, some may not be supported.
# c1 <- c("101","10","115","132","21","112")
# c2 <- c("100","101","0","100","21","110")

# gender <- rep(c("M","F"),3)
# loc2 <- locus(c2,c2,chrom="X",locus.alias="DXS1234",x.linked=T,sex=gender)
}
\keyword{classes}
% docclass is function
% Converted by Sd2Rd version 1.21.

\eof
\name{louis.info}
\alias{louis.info}
\title{
  Louis Information for haplo.glm
}
\description{
For internal use within the haplo.stats library
}
\usage{
louis.info(fit)
}
\arguments{

\item{fit}{

}
}
\value{
}
\section{Side Effects}{

}
\details{

}
\section{References}{

}
\seealso{

}
\examples{

}
\keyword{}
% docclass is function
% Converted by Sd2Rd version 1.21.

\eof
\name{mf.gindx}
\alias{mf.gindx}
\title{
  Model Frame Genotype Index to Account for Missing Data in haplo.glm
}
\description{
For internal use within the haplo.stats library
}
\usage{
mf.gindx(m)
}
\arguments{

\item{m}{

}
}
\value{
}
\section{Side Effects}{

}
\details{

}
\section{References}{

}
\seealso{

}
\examples{

}
\keyword{}
% docclass is function
% Converted by Sd2Rd version 1.21.

\eof
\name{na.geno.keep}
\alias{na.geno.keep}
\title{
  Find non-missing rows in the genotype matrix of the model.frame
}
\description{
An internal function for the haplo.stats package
}
\usage{
na.geno.keep(m)
}
\arguments{

\item{m}{

}
}
\value{
}
\section{Side Effects}{

}
\details{

}
\section{References}{

}
\seealso{

}
\examples{

}
\keyword{}
% docclass is function
% Converted by Sd2Rd version 1.21.

\eof
\name{plot.haplo.score}
\alias{plot.haplo.score}
\title{
  Plot Haplotype Frequencies versus Haplotype Score Statistics
}
\description{
Method function to plot a class of type haplo.score
}
\usage{
plot.haplo.score(x, ...)
}
\arguments{
\item{x}{
The object returned from haplo.score (which has class haplo.score).
}
\item{\dots }{
Dynamic parameter for the values of additional parameters for 
the plot method.  
}
}
\value{
Nothing is returned.
}
\section{Side Effects}{

}
\details{
This is a plot method function used to plot haplotype frequencies on
the x-axis and haplotype-specific scores on the y-axis. Because
haplo.score is a class, the generic plot function 
can be used, which in turn calls this plot.haplo.score function.
}
\section{References}{
Schaid DJ, Rowland CM, Tines DE, Jacobson RM,  Poland  GA.
"Score tests for association of traits with haplotypes when
linkage phase is ambiguous." Amer J Hum Genet. 70 (2002):  425-434.
}
\seealso{
haplo.score
}
\examples{
  setupData(hla.demo)
  geno <- as.matrix(hla.demo[,c(17,18,21:24)])
  keep <- !apply(is.na(geno) | geno==0, 1, any)
  hla.demo <- hla.demo[keep,]
  geno <- geno[keep,]
  attach(hla.demo)
  label <- c("DQB","DRB","B")
 
# For quantitative, normally distributed trait:

  score.gaus <- haplo.score(resp, geno, locus.label=label, 
                            trait.type = "gaussian")

  plot.haplo.score(score.gaus)
}
\keyword{}
% docclass is function
% Converted by Sd2Rd version 1.21.

\eof
\name{plot.haplo.score.slide}
\alias{plot.haplo.score.slide}
\title{
  Plot a haplo.score.slide Object 
}
\description{
Method function to plot an object of class haplo.score.slide.  The
p-values from haplo.score.slide are for sub-haplotypes of a larger
chromosomal region, and these are plotted to visualize the change in
p-values as the sub-haplotype "slides" over a chromosome. Plot
-log10(p-value) on the y-axis vs. the loci over which it was computed
on the x-axis.
}
\usage{
plot.haplo.score.slide(x, pval="global", dist.vec=1:x$n.loci, 
                       cex=.8, srt=270, ...)
}
\arguments{
\item{x}{
The object returned from haplo.score.slide
}
\item{pval}{
Character string for the choice of p-value to plot. Options are:
"global" (the global score statistic p-value based on an asymptotic
chi-square distribution), "global.sim" (the global score statistic
simulated p-value), and "max.sim" (the simulated p-value for the
maximum score statistic).
}
\item{dist.vec }{
Numeric vector for position (i.e. in cM) of the loci along a
chromosome. Distances on x-axis will correspond to these positions. 
}
\item{cex}{
Character expansion size.
}
\item{srt}{
String rotation in degrees measured counterclockwise from
horizontal.  Applies to x-axis (locus) labels.  
}
\item{\dots }{
Dynamic parameter for the values of additional parameters for 
the plot method.  
}
}
\value{
Nothing is returned.
}
\section{Side Effects}{

}
\details{
The x-axis has tick marks for all loci.  The y-axis is the -log10() of
the selected p-value.  For each haplo.score result, plot a horizontal
line at the height of -log10(p-value) drawn across the loci over which
it was calculated.  Therefore a p-value of 0.001 for the first 3 loci
will plot as a horizontal line plotted at y=3 covering the first three
tick marks.  
}
\section{References}{
Schaid DJ, Rowland CM, Tines DE, Jacobson RM,  Poland  GA.
"Score tests for association of traits with haplotypes when
linkage phase is ambiguous." Amer J Hum Genet. 70 (2002):  425-434.
}
\seealso{
\code{\link{haplo.score.slide}}
}
\examples{
#This example is run completely in the haplo.score.slide

#   setupData(hla.demo)
#   attach(hla.demo)
#   geno.11 <- hla.demo[,-c(1:4)]
#   label.11 <- c("DPB","DPA","DMA","DMB","TAP1","TAP2","DQB","DQA","DRB","B","A")

#For an ordinal trait, slide by 3 loci, and simulate p-values:
#   y.ord <- as.numeric(resp.cat)
#   slide.ord.sim <-  haplo.score.slide(y.ord, geno.11, trait.type = "ordinal",
#                              n.slide=3, locus.label=label.11, simulate=TRUE,
#                              sim.control=score.sim.control(min.sim=500))

#   print(slide.ord.sim)
#   plot(slide.ord.sim)
#   plot(slide.ord.sim, pval="global.sim")
#   plot(slide.ord.sim, pval="max.sim")
}
\keyword{}
% docclass is function
% Converted by Sd2Rd version 1.21.

\eof
\name{print.haplo.em}
\alias{print.haplo.em}
\title{
  Print contents of a haplo.em object
}
\description{
Print a data frame with haplotypes and their frequencies.  Also print
likelihood information.
}
\usage{
print.haplo.em(x, ...)
}
\arguments{

\item{x}{
A haplo.em object
}
\item{\dots }{
optional arguments for print
}
}
\value{
Nothing is returned
}
\section{Side Effects}{

}
\details{

}
\section{References}{

}
\seealso{
haplo.em
}
\examples{

}
\keyword{}
% docclass is function
% Converted by Sd2Rd version 1.21.

\eof
\name{print.haplo.glm}
\alias{print.haplo.glm}
\title{
  Print a contents of a haplo.glm object
}
\description{
Print model information and then haplotype information. 
}
\usage{
print.haplo.glm(x, print.all.haplo=FALSE, digits = 
                max(options()$digits - 4, 3), ...)
}
\arguments{

\item{x}{
A haplo.glm object
}
\item{print.all.haplo }{
Logical.  If TRUE, print all haplotypes considered in the model.
}
\item{digits}{
Number of numeric digits to print.
}
\item{\dots }{
Optional arguments for print method
}
}
\value{
Nothing is returned
}
\section{Side Effects}{

}
\details{

}
\section{References}{

}
\seealso{
haplo.glm
}
\examples{

}
\keyword{}
% docclass is function
% Converted by Sd2Rd version 1.21.

\eof
\name{print.haplo.group}
\alias{print.haplo.group}
\title{
  Print a haplo.group object
}
\description{
Method function to print a class of type haplo.group
}
\usage{
print.haplo.group(x, digits=max(options()$digits-2, 5), ...)
}
\arguments{
\item{x}{
The object returned from haplo.group (which has old class haplo.group).
}
\item{digits}{
Set the number of significant digits to print for haplotype probabilities.
}
\item{\dots}{
Optional arguments for the print method
}
}
\value{
Nothing is returned.
}
\section{Side Effects}{

}
\details{
This is a print method function used to print information from the
haplo.group class, with haplotype-specific information given in a
table. Because haplo.score is a class, the generic print function 
can be used, which in turn calls this print.haplo.group function.
}
\section{References}{
Schaid DJ, Rowland CM, Tines DE, Jacobson RM, Poland  GA.
Expected haplotype frequencies for association of traits with 
haplotypes when linkage phase is ambiguous. 
Submitted to Amer J Hum Genet.
}
\seealso{
haplo.score, haplo.group, haplo.em
}
\examples{

}
\keyword{}
% docclass is function
% Converted by Sd2Rd version 1.21.

\eof
\name{print.haplo.score}
\alias{print.haplo.score}
\title{
  Print a haplo.score object
}
\description{
Method function to print a class of type haplo.score
}
\usage{
print.haplo.score(x, digits, ...)
}
\arguments{
\item{x}{
The object returned from haplo.score (which has class haplo.score).
}
\item{digits}{
Number of digits to round the numeric output.
}
\item{\dots }{
Dynamic parameter for the values of additional parameters for 
the print method.  
}
}
\value{
Nothing is returned.
}
\section{Side Effects}{

}
\details{
This is a print method function used to print information from
haplo.score class, with haplotype-specific information given in a
table. Because haplo.score is a class, the generic print function 
can be used, which in turn calls this print.haplo.score function.
}
\seealso{
haplo.score
}
\examples{

}
\keyword{}
% docclass is function
% Converted by Sd2Rd version 1.21.

\eof
\name{print.haplo.score.merge}
\alias{print.haplo.score.merge}
\title{
  Print a haplo.score.merge object
}
\description{
Method function to print a class of type haplo.score.merge
}
\usage{
print.haplo.score.merge(x, order.by="score", all.haps=FALSE, 
                        digits=max(options()$digits-2, 5), ...)
}
\arguments{
\item{x}{
The object returned from haplo.score.merge (which has old class \{S\} 
haplo.score.merge).
}
\item{order.by}{
Column of the haplo.score.merge object by which to order the results.
}
\item{all.haps}{
Logical, if (T)rue prints a row for all haplotypes.  If (F)alse, the
default, only prints the haplotypes kept in haplo.score for modelling.
}
\item{digits}{
Set the number of significant digits to print for the numeric output.
}
\item{\dots }{
Dynamic parameter for the values of additional parameters for 
the print method.  
}
}
\value{
Nothing is returned.
}
\section{Side Effects}{

}
\details{
This is a print method function used to print information from the
haplo.score.merge class. Because haplo.score.merge is a class, 
the generic print function can be used, which in turn calls this 
print.haplo.score.merge function.
}
\section{References}{
Schaid DJ, Rowland CM, Tines DE, Jacobson RM, Poland  GA.
Expected haplotype frequencies for association of traits with 
haplotypes when linkage phase is ambiguous. 
Submitted to Amer J Hum Genet.
}
\seealso{
haplo.score.merge, haplo.score, haplo.group
}
\examples{
#see example for haplo.score.merge
}
\keyword{}
% docclass is function
% Converted by Sd2Rd version 1.21.

\eof
\name{print.haplo.score.slide}
\alias{print.haplo.score.slide}
\title{
  Print the contents of a haplo.score.slide object
}
\description{
Print the data frame returned from haplo.score.slide
}
\usage{
print.haplo.score.slide(x, digits=max(options()$digits - 2, 5), ...)
}
\arguments{

\item{x}{
A haplo.score.slide object
}
\item{digits}{
Number of digits to print for numeric output
}
\item{\dots }{
Optional arguments for the print method
}
}
\value{
}
\section{Side Effects}{

}
\details{

}
\section{References}{

}
\seealso{

}
\examples{

}
\keyword{}
% docclass is function
% Converted by Sd2Rd version 1.21.

\eof
\name{printBanner}
\alias{printBanner}
\title{
  Print a nice banner
}
\description{

}
\usage{
printBanner(str, banner.width=80, char.perline=60, border="=")
}
\arguments{
\item{str}{
character string - a title within the banner
}
\item{banner.width }{
width of banner
}
\item{char.perline }{
number of characters per line for the title
}
\item{border}{
type of character for the border
}
}
\value{
}
\section{Side Effects}{

}
\details{

}
\section{References}{

}
\seealso{

}
\examples{
printBanner("This is a pretty banner", banner.width=40, char.perline=30)

#========================================
#         This is a pretty banner
#========================================
}
\keyword{}
% docclass is function
% Converted by Sd2Rd version 1.21.

\eof
\name{residScaledGlmFit}
\alias{residScaledGlmFit}
\title{
  Scaled Residuals for GLM fit
}
\description{
For internal use within the haplo.stats library
}
\usage{
residScaledGlmFit(fit)
}
\arguments{

\item{fit}{

}
}
\value{
}
\section{Side Effects}{

}
\details{

}
\section{References}{

}
\seealso{

}
\examples{

}
\keyword{}
% docclass is function
% Converted by Sd2Rd version 1.21.

\eof
\name{score.sim.control}
\alias{score.sim.control}
\title{
  Create the list of control parameters for simulations in haplo.score
}
\description{
In the call to haplo.score, the sim.control
parameter is a list of parameters that control the simulations. This
list is created by this function, score.sim.control, making it easy to
change the default values.
}
\usage{
score.sim.control(p.threshold=0.25, min.sim=1000, max.sim=20000.,verbose=FALSE)
}
\arguments{

\item{p.threshold }{
A paremeter used to determine p-value precision from Besag and
Clifford (1991).  For a p-value calculated after min.sim simulations,
continue doing simulations until the p-value's sample standard error is
less than p.threshold * p-value.  The dafault value for p.threshold = 1/4
corresponds approximately to having a two-sided 95\% confidence
interval for the p-value with a width as wide as the p-value itself.
Therefore, simulations are more precise for smaller p-values.
Additionally, since simulations are stopped as soon as this criteria
is met, p-values may be biased high.  
}
\item{min.sim }{
The minimum number of simulations to run.
}
\item{max.sim }{
The upper limit of simulations allowed.  When the number of simulations reaches
max.sim, p-values are approximated based on simulation results at that
time.
}
\item{verbose}{
Logical, if (T)rue, print updates from every simulation to the
screen.  If (F)alse, do not print these details.
}
}
\value{
A list of the control parameters:

\item{p.threshold}{
As described above
}
\item{min.sim}{
As described above.  If run-time is an issue, a
lower minimum (e.g. 500) may be useful.
}
\item{max.sim}{
As described above
}
\item{verbose}{
As described above
}
}
\section{Side Effects}{

}
\details{
In simulations for haplo.score, employ the simulation p-value
precision criteria of Besag and Clifford (1991).  The criteria
ensures both the global and the maximum score statistic simulated
p-values be precise for small p-values.  First, perform min.sim
simulations to guarantee sufficient precision for the score
statistics on individual haplotypes.  Then continue simulations as
needed until simulated p-values for both the global and max score
statistics meet precision requirements set by p.threshold.
}
\section{References}{
Besag, J and Clifford, P.  "Sequential Monte Carlo p-values."
Biometrika.  78, no. 2 (1991): 301-304.
}
\seealso{
\code{\link{haplo.score}}
}
\examples{
# it would be used in haplo.score as appears below
#
# score.sim.500 <- haplo.score(y, geno, trait.type="gaussian", simulate=T, 
#                sim.control=score.sim.control(min.sim=500, max.sim=2000)
}
\keyword{}
% docclass is function
% Converted by Sd2Rd version 1.21.

\eof
\name{setupData}
\alias{setupData}
\title{
  Set up an example dataset provided within the library.
}
\description{
This function defines an alias function to run exactly as data() in R
and does nothing in Splus.  R keeps a data set within the working data
frame, so we only want to load data it when calling an example.  Splus
keeps it in background, so it is already loaded upon library(mypkg).
}
\usage{
setupData(...)
}
\arguments{

\item{\dots }{
The name of a dataset provided within the Splus/R library.
}
}
\value{
}
\section{Side Effects}{

}
\details{

}
\section{References}{

}
\seealso{

}
\examples{

}
\keyword{}
% docclass is function
% Converted by Sd2Rd version 1.21.

\eof
\name{setupGeno}
\alias{setupGeno}
\title{
  Create a group of locus objects from a genotype matrix, assign to
'model.matrix' class.  
}
\description{
The function makes each pair of columns a locus object, which
recodes alleles to numeric and saves the original alleles as an
attribute of the model.matrix. 
}
\usage{
setupGeno(geno, miss.val=c(0,NA))
}
\arguments{
\item{geno}{
Matrix of alleles, such that each locus has a pair of adjacent
columns of alleles, and the order of columns corresponds to the
order of loci on a chromosome. If there are K loci, then
ncol(geno) = 2*K. Rows represent alleles for each subject.
}
\item{miss.val }{
A vector of codes denoting missing values for allele1 and
allele2. Note that NA will always be treated as a missing value, even
if not specified in miss.val.  Also note that if multiple missing
value codes are specified, the original missing value code for a
specific individual can not be retrieved from the loci object.
}
}
\value{
A 'model.matrix' object with the alleles recoded to numeric values,
and the original values are stored in the 'unique.alleles' attribute.
The ith item of the unique.alleles list is a vector of unique alleles
for the ith locus.
}
\section{Side Effects}{

}
\details{

}
\section{References}{

}
\note{
A matrix that contains all elements of mode character will be sorted
in alphabetic order.
}
\seealso{
locus, loci, haplo.glm
}
\examples{
# Create some loci to work with
a1 <- 1:6
a2 <- 7:12

b1 <- c("A","A","B","C","E","D")
b2 <-c("A","A","C","E","F","G")

c1 <- c("101","10","115","132","21","112")
c2 <- c("100","101","0","100","21","110")

myGeno <- data.frame(a1,a2,b1,b2,c1,c2)
myGeno <- setupGeno(myGeno)
myGeno

attributes(myGeno)$unique.alleles
}
\keyword{}
% docclass is function
% Converted by Sd2Rd version 1.21.

\eof
\name{summary.haplo.em}
\alias{summary.haplo.em}
\title{
  Summarize contents of a haplo.em object
}
\description{
Display haplotype pairs and their posterior probabilities by subject.
Also display a table with number of max haplotype pairs for a
subject versus how many were kept (max vs. used).  
}
\usage{
summary.haplo.em(object, show.haplo=FALSE, ...)
}
\arguments{
\item{object}{
A haplo.em object
}
\item{show.haplo }{
Logical. If TRUE, show the alleles of the haplotype pairs, otherwise show
only the recoded values.
}
\item{\dots }{
Optional arguments for the summary method
}
}
\value{
}
\section{Side Effects}{

}
\details{

}
\section{References}{

}
\seealso{

}
\examples{

}
\keyword{}
% docclass is function
% Converted by Sd2Rd version 1.21.

\eof
\name{summaryGeno}
\alias{summaryGeno}
\title{
  Summarize Full Haplotype Enumeration on Genotype Matrix 
}
\description{
Provide a summary of missing allele information for each individual 
in the genotype matrix.  The number of loci missing zero, one, or two 
alleles is computed, as well as the total number of haplotype pairs 
that could result from the observed phenotype.
}
\usage{
summaryGeno(geno, miss.val=0)
}
\arguments{
\item{geno}{
Matrix of alleles, such that each locus has a pair of adjacent columns
of alleles, and the order of columns corresponds to the order of loci 
on a chromosome. If there are K loci, then geno has 2*K columns. Rows 
represent all observed alleles for each subject.
}
\item{miss.val }{
Vector of codes for allele missing values.
}
}
\value{
Data frame with columns representing the number of loci with zero,
one, and two missing alleles, then the total haplotype pairs resulting
from full enumeration of the phenotype.
}
\section{Side Effects}{

}
\details{
After getting information on the individual loci, this function makes 
a call to geno.count.pairs().  The E-M steps to estimate haplotype 
frequencies considers haplotypes that could result from a phenotype
with a missing allele.  It will not remove a subject's phenotype, only
the unlikely haplotypes that result from it.  
}
\seealso{
\code{\link{geno.count.pairs}},
\code{\link{haplo.em}}
}
\examples{

}
\keyword{}
% docclass is function
% Converted by Sd2Rd version 1.21.

\eof
\name{varfunc.glm.fit}
\alias{varfunc.glm.fit}
\title{
  Variance Function for GLM
}
\description{
For internal use within the haplo.stats library
}
\usage{
varfunc.glm.fit(fit)
}
\arguments{

\item{fit}{

}
}
\value{
}
\section{Side Effects}{

}
\details{

}
\section{References}{

}
\seealso{

}
\examples{

}
\keyword{}
% docclass is function
% Converted by Sd2Rd version 1.21.

\eof
